@@ -60,8 +60,8 @@ DeviceWidget::DeviceWidget(MainWindow* parent, QByteArray deviceType) :
     connect(portList, static_cast<void(QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &DeviceWidget::onPortChange);
     connect(offsetButton, static_cast<void(QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, &DeviceWidget::onOffsetChange);
 
-    for (unsigned i = 0; i < PA_CHANNELS_MAX; i++)
-        channels[i] = NULL;
+    for (auto & channel : channels)
+        channel = nullptr;
 
 
     // FIXME:
@@ -151,7 +151,7 @@ void DeviceWidget::onOffsetChange() {
     card_name = QByteArray::fromStdString(card_stream.str());
 
     if (!(o = pa_context_set_port_latency_offset(get_context(),
-            card_name, activePort, offset, NULL, NULL))) {
+            card_name, activePort, offset, nullptr, nullptr))) {
         show_error(tr("pa_context_set_port_latency_offset() failed").toUtf8().constData());
         return;
     }
@@ -189,11 +189,11 @@ void DeviceWidget::prepareMenu() {
 
     portList->clear();
     /* Fill the ComboBox's Model */
-    for (uint32_t i = 0; i < ports.size(); ++i) {
-        QByteArray name = ports[i].first;
-        QString desc = ports[i].second;
+    for (auto & port : ports) {
+        QByteArray name = port.first;
+        QString desc = port.second;
         portList->addItem(desc, name);
-        if (ports[i].first == activePort)
+        if (port.first == activePort)
             active_idx = idx;
         idx++;
     }
@@ -201,7 +201,7 @@ void DeviceWidget::prepareMenu() {
     if (active_idx >= 0)
         portList->setCurrentIndex(active_idx);
 
-    if (ports.size() > 0) {
+    if (!ports.empty()) {
         portSelect->show();
 
         if (pa_context_get_server_protocol_version(get_context()) >= 27) {
@@ -236,7 +236,7 @@ void DeviceWidget::renamePopup() {
         pa_operation* o;
         gchar *key = g_markup_printf_escaped("%s:%s", mDeviceType.constData(), name.constData());
 
-        if (!(o = pa_ext_device_manager_set_device_description(get_context(), key, new_name.toUtf8().constData(), NULL, NULL)))
+        if (!(o = pa_ext_device_manager_set_device_description(get_context(), key, new_name.toUtf8().constData(), nullptr, nullptr)))
             show_error(tr("pa_ext_device_manager_set_device_description() failed").toUtf8().constData());
         else
             pa_operation_unref(o);
